@@ -208,7 +208,7 @@ class Client(Callbacks, SocketHandler):
         })
 
         response = requests.post(f"{self.apie}/g/s/auth/login", headers=self.new_headers, data=data, proxies=self.proxies, verify=self.certificatePath)
-        print(json.loads(response.text)["api:statuscode"])
+        #print(json.loads(response.text)["api:statuscode"])
         self.run_socket()
         if json.loads(response.text)["api:statuscode"] != 0: return exceptions.CheckException(json.loads(response.text))
 
@@ -627,6 +627,7 @@ class Client(Callbacks, SocketHandler):
                 '__response': {}
         }}}) ; 
         req=requests.post("https://aminoapps.com/api/register",data=data,headers=self.reg_headers)
+        print(req.text)
         if req.status_code != 200 : raise TypeError(req.text)
         #print(req.text)
     
